@@ -1,13 +1,7 @@
-# Licensed to Elasticsearch B.V under one or more agreements.
-# Elasticsearch B.V licenses this file to you under the Apache 2.0 License.
-# See the LICENSE file in the project root for more information
-
-package Search::Elasticsearch::Client::5_0::Direct::Cluster;
-$Search::Elasticsearch::Client::5_0::Direct::Cluster::VERSION = '7.30_1'; # TRIAL
-
-$Search::Elasticsearch::Client::5_0::Direct::Cluster::VERSION = '7.301';
+package Search::Elasticsearch::Client::6_0::Direct::Cluster;
+$Search::Elasticsearch::Client::6_0::Direct::Cluster::VERSION = '6.80';
 use Moo;
-with 'Search::Elasticsearch::Client::5_0::Role::API';
+with 'Search::Elasticsearch::Client::6_0::Role::API';
 with 'Search::Elasticsearch::Role::Client::Direct';
 __PACKAGE__->_install_api('cluster');
 
@@ -19,11 +13,11 @@ __PACKAGE__->_install_api('cluster');
 
 =head1 NAME
 
-Search::Elasticsearch::Client::5_0::Direct::Cluster - A client for running cluster-level requests
+Search::Elasticsearch::Client::6_0::Direct::Cluster - A client for running cluster-level requests
 
 =head1 VERSION
 
-version 7.30_1
+version 6.80
 
 =head1 DESCRIPTION
 
@@ -54,6 +48,7 @@ Query string parameters:
     C<timeout>,
     C<wait_for_active_shards>,
     C<wait_for_events>,
+    C<wait_for_no_initializing_shards>,
     C<wait_for_no_relocating_shards>,
     C<wait_for_nodes>,
     C<wait_for_status>
@@ -108,7 +103,7 @@ For instance:
 
     $response = $e->cluster->put_settings(
         body => {
-            transient => { "discovery.zen.minimum_master_nodes" => 5 }
+            transient => { "discovery.zen.minimum_master_nodes" => 6 }
         }
     );
 
@@ -148,7 +143,9 @@ Query string parameters:
     C<human>,
     C<ignore_unavailable>,
     C<local>,
-    C<master_timeout>
+    C<master_timeout>,
+    C<wait_for_metadata_version>,
+    C<wait_for_timeout>
 
 See the L<cluster state docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/cluster-state.html>
 for more information.
