@@ -1,13 +1,7 @@
-# Licensed to Elasticsearch B.V under one or more agreements.
-# Elasticsearch B.V licenses this file to you under the Apache 2.0 License.
-# See the LICENSE file in the project root for more information
-
-package Search::Elasticsearch::Client::5_0::Direct::Nodes;
-$Search::Elasticsearch::Client::5_0::Direct::Nodes::VERSION = '7.30_1'; # TRIAL
-
-$Search::Elasticsearch::Client::5_0::Direct::Nodes::VERSION = '7.301';
+package Search::Elasticsearch::Client::6_0::Direct::Nodes;
+$Search::Elasticsearch::Client::6_0::Direct::Nodes::VERSION = '6.80';
 use Moo;
-with 'Search::Elasticsearch::Client::5_0::Role::API';
+with 'Search::Elasticsearch::Client::6_0::Role::API';
 with 'Search::Elasticsearch::Role::Client::Direct';
 __PACKAGE__->_install_api('nodes');
 
@@ -19,11 +13,11 @@ __PACKAGE__->_install_api('nodes');
 
 =head1 NAME
 
-Search::Elasticsearch::Client::5_0::Direct::Nodes - A client for running node-level requests
+Search::Elasticsearch::Client::6_0::Direct::Nodes - A client for running node-level requests
 
 =head1 VERSION
 
-version 7.30_1
+version 6.80
 
 =head1 DESCRIPTION
 
@@ -97,11 +91,11 @@ Allowed metrics are:
     C<transport>
 
 If the C<indices> metric (or C<_all>) is specified, then
-L<indices_stats|Search::Elasticsearch::Client::5_0::Direct::Indices/indices_stats()>
+L<indices_stats|Search::Elasticsearch::Client::6_0::Direct::Indices/indices_stats()>
 information is returned on a per-node basis. Which indices stats are
 returned can be controlled with the C<index_metric> parameter:
 
-    $response = $e->cluster->node_stats(
+    $response = $e->nodes->stats(
         node_id       => 'node_1',
         metric        => ['indices','fs']
         index_metric  => ['docs','fielddata']
@@ -136,7 +130,7 @@ Query string parameters:
     C<level>,
     C<types>
 
-See the L<node_stats docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/cluster-nodes-stats.html>
+See the L<stats docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/cluster-nodes-stats.html>
 for more information.
 
 =head2 C<hot_threads()>
@@ -161,6 +155,41 @@ Query string parameters:
 See the L<hot_threads docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/cluster-nodes-hot-threads.html>
 for more information.
 
+=head2 C<reload_secure_settings()>
+
+    $response = $e->nodes->reload_secure_settings(
+        node_id => $node_id | \@node_ids    # optional
+    );
+
+The C<reload_secure_settings()> API will reload the reloadable settings stored in the keystore
+on each node.
+
+Query string parameters:
+    C<error_trace>,
+    C<filter_path>,
+    C<human>,
+    C<timeout>
+
+See the L<reload-secure-settings docs|https://www.elastic.co/guide/en/elasticsearch/reference/current/secure-settings.html>
+for more information.
+
+=head2 C<usage()>
+
+    $response = $e->nodes->usage(
+        node_id => $node_id | \@node_ids       # optional
+        metric  => $metric  | \@metrics        # optional
+    )
+
+The C<usage()> API retrieve sinformation on the usage of features for each node.
+
+Query string parameters:
+    C<error_trace>,
+    C<human>,
+    C<timeout>
+
+See the L<nodes_usage docs|https://www.elastic.co/guide/en/elasticsearch/reference/current/cluster-nodes-usage.html>
+for more information.
+
 =head1 AUTHOR
 
 Enrico Zimuel <enrico.zimuel@elastic.co>
