@@ -1,13 +1,7 @@
-# Licensed to Elasticsearch B.V under one or more agreements.
-# Elasticsearch B.V licenses this file to you under the Apache 2.0 License.
-# See the LICENSE file in the project root for more information
-
-package Search::Elasticsearch::Client::5_0::Direct::Tasks;
-$Search::Elasticsearch::Client::5_0::Direct::Tasks::VERSION = '7.30_1'; # TRIAL
-
-$Search::Elasticsearch::Client::5_0::Direct::Tasks::VERSION = '7.301';
+package Search::Elasticsearch::Client::6_0::Direct::Tasks;
+$Search::Elasticsearch::Client::6_0::Direct::Tasks::VERSION = '6.80';
 use Moo;
-with 'Search::Elasticsearch::Client::5_0::Role::API';
+with 'Search::Elasticsearch::Client::6_0::Role::API';
 with 'Search::Elasticsearch::Role::Client::Direct';
 __PACKAGE__->_install_api('tasks');
 
@@ -19,11 +13,11 @@ __PACKAGE__->_install_api('tasks');
 
 =head1 NAME
 
-Search::Elasticsearch::Client::5_0::Direct::Tasks - A client for accessing the Task Management API
+Search::Elasticsearch::Client::6_0::Direct::Tasks - A client for accessing the Task Management API
 
 =head1 VERSION
 
-version 7.30_1
+version 6.80
 
 =head1 DESCRIPTION
 
@@ -50,8 +44,8 @@ Query string parameters:
     C<group_by>,
     C<human>,
     C<nodes>,
-    C<parent_node>,
     C<parent_task_id>,
+    C<timeout>,
     C<wait_for_completion>
 
 See the L<task management docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/tasks.html>
@@ -76,7 +70,7 @@ for more information.
 =head2 C<cancel()>
 
     $response = $e->tasks->cancel(
-        task_id => $task_id  # option
+        task_id => $task_id  # required
     );
 
 The C<cancel()> method attempts to cancel the specified C<task_id> or multiple tasks.
@@ -86,8 +80,8 @@ Query string parameters:
     C<error_trace>,
     C<human>,
     C<nodes>,
-    C<parent_node>,
-    C<parent_task_id>
+    C<parent_task_id>,
+    C<timeout>
 
 See the L<task management docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/tasks.html>
 for more information.
