@@ -1,11 +1,5 @@
-# Licensed to Elasticsearch B.V under one or more agreements.
-# Elasticsearch B.V licenses this file to you under the Apache 2.0 License.
-# See the LICENSE file in the project root for more information
-
-package Search::Elasticsearch::Client::5_0::Scroll;
-$Search::Elasticsearch::Client::5_0::Scroll::VERSION = '7.30_1'; # TRIAL
-
-$Search::Elasticsearch::Client::5_0::Scroll::VERSION = '7.301';
+package Search::Elasticsearch::Client::6_0::Scroll;
+$Search::Elasticsearch::Client::6_0::Scroll::VERSION = '6.80';
 use Moo;
 use Search::Elasticsearch::Util qw(parse_params throw);
 use namespace::clean;
@@ -13,7 +7,7 @@ use namespace::clean;
 has '_buffer' => ( is => 'ro' );
 
 with 'Search::Elasticsearch::Role::Is_Sync',
-    'Search::Elasticsearch::Client::5_0::Role::Scroll';
+    'Search::Elasticsearch::Client::6_0::Role::Scroll';
 
 #===================================
 sub BUILDARGS {
@@ -30,6 +24,9 @@ sub BUILDARGS {
     my $results      = $es->search($params);
 
     my $total = $results->{hits}{total};
+    if (ref $total) {
+        $total = $total->{value}
+    }
 
     return {
         es           => $es,
@@ -115,7 +112,7 @@ sub finish {
     my %args
         = $self->scroll_in_qs
         ? ( scroll_id => $scroll_id )
-        : ( body => { scroll_id => [$scroll_id] } );
+        : ( body => { scroll_id => $scroll_id } );
     eval { $self->es->clear_scroll(%args) };
     return 1;
 }
@@ -128,11 +125,11 @@ sub finish {
 
 =head1 NAME
 
-Search::Elasticsearch::Client::5_0::Scroll - A helper module for scrolled searches
+Search::Elasticsearch::Client::6_0::Scroll - A helper module for scrolled searches
 
 =head1 VERSION
 
-version 7.30_1
+version 6.80
 
 =head1 SYNOPSIS
 
@@ -162,17 +159,17 @@ until there are no more matching results, much like a cursor in an SQL
 database.
 
 Unlike paginating through results (with the C<from> parameter in
-L<search()|Search::Elasticsearch::Client::5_0::Direct/search()>),
+L<search()|Search::Elasticsearch::Client::6_0::Direct/search()>),
 scrolled searches take a snapshot of the current state of the index. Even
 if you keep adding new documents to the index or updating existing documents,
 a scrolled search will only see the index as it was when the search began.
 
 This module is a helper utility that wraps the functionality of the
-L<search()|Search::Elasticsearch::Client::5_0::Direct/search()> and
-L<scroll()|Search::Elasticsearch::Client::5_0::Direct/scroll()> methods to make
+L<search()|Search::Elasticsearch::Client::6_0::Direct/search()> and
+L<scroll()|Search::Elasticsearch::Client::6_0::Direct/scroll()> methods to make
 them easier to use.
 
-This class does L<Search::Elasticsearch::Client::5_0::Role::Scroll> and
+This class does L<Search::Elasticsearch::Client::6_0::Role::Scroll> and
 L<Search::Elasticsearch::Role::Is_Sync>.
 
 =head1 USE CASES
@@ -237,7 +234,7 @@ C<client_id>:
 
 Very often the I<something> that you will want to do with these results
 involves bulk-indexing them into a new index. The easiest way to
-do this is to use the built-in L<Search::Elasticsearch::Client::5_0::Direct/reindex()>
+do this is to use the built-in L<Search::Elasticsearch::Client::6_0::Direct/reindex()>
 functionality provided by Elasticsearch.
 
 =head1 METHODS
@@ -253,13 +250,13 @@ functionality provided by Elasticsearch.
         %search_params
     );
 
-The L<Search::Elasticsearch::Client::5_0::Direct/scroll_helper()> method loads
-L<Search::Elasticsearch::Client::5_0::Scroll> class and calls L</new()>,
+The L<Search::Elasticsearch::Client::6_0::Direct/scroll_helper()> method loads
+L<Search::Elasticsearch::Client::6_0::Scroll> class and calls L</new()>,
 passing in any arguments.
 
 You can specify a C<scroll> duration (which defaults to C<"1m">) and
 C<scroll_in_qs> (which defaults to C<false>). Any other parameters are
-passed directly to L<Search::Elasticsearch::Client::5_0::Direct/search()>.
+passed directly to L<Search::Elasticsearch::Client::6_0::Direct/search()>.
 
 The C<scroll> duration tells Elasticearch how long it should keep the scroll
 alive.  B<Note>: this duration doesn't need to be long enough to process
@@ -268,7 +265,7 @@ The expiry gets renewed for another C<scroll> period every time new
 a new batch of results is retrieved from the cluster.
 
 By default, the C<scroll_id> is passed as the C<body> to the
-L<scroll|Search::Elasticsearch::Client::5_0::Direct/scroll()> request.
+L<scroll|Search::Elasticsearch::Client::6_0::Direct/scroll()> request.
 To send it in the query string instead, set C<scroll_in_qs> to a true value,
 but be aware: when querying very many indices, the scroll ID can become
 too long for intervening proxies.
@@ -314,7 +311,7 @@ the buffer.
 
 The C<finish()> method clears out the buffer, sets L</is_finished()> to C<true>
 and tries to clear the C<scroll_id> on Elasticsearch.  This API is only
-supported since v0.90.5, but the call to C<clear_scroll> is wrapped in an
+supported since v0.90.6, but the call to C<clear_scroll> is wrapped in an
 C<eval> so the C<finish()> method can be safely called with any version
 of Elasticsearch.
 
@@ -365,11 +362,11 @@ How long the original search plus all subsequent batches took, in milliseconds.
 
 =over
 
-=item * L<Search::Elasticsearch::Client::5_0::Direct/search()>
+=item * L<Search::Elasticsearch::Client::6_0::Direct/search()>
 
-=item * L<Search::Elasticsearch::Client::5_0::Direct/scroll()>
+=item * L<Search::Elasticsearch::Client::6_0::Direct/scroll()>
 
-=item * L<Search::Elasticsearch::Client::5_0::Direct/reindex()>
+=item * L<Search::Elasticsearch::Client::6_0::Direct/reindex()>
 
 =back
 
